﻿using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using System;
using Windows.UI;
using Windows.Storage;
using Windows.Storage.Pickers;
using Windows.Storage.Streams;
using Windows.UI.Text;

namespace richEditBoxSample
{
    /// <summary>
    /// 可用于自身或导航至 Frame 内部的空白页。
    /// </summary>
    public sealed partial class MainPage : Page
    {
        public MainPage()
        {
            this.InitializeComponent();
        }

        private void OnFontsizeItemClick(object sender, ItemClickEventArgs e)
        {
            // 获取被单击项的值
            double val = (double)e.ClickedItem;
            // 设置选定文本的字体大小
            editbox.Document.Selection.CharacterFormat.Size = (float)val;
        }

        private void OnColorItemClick(object sender, ItemClickEventArgs e)
        {
            // 取出被单击项的颜色对象
            Color c = (Color)e.ClickedItem;
            // 设置文本颜色
            editbox.Document.Selection.CharacterFormat.ForegroundColor = c;
        }

        private async void OnInsertImage(object sender, RoutedEventArgs e)
        {
            FileOpenPicker picker = new FileOpenPicker();
            picker.FileTypeFilter.Add(".jpg");
            picker.FileTypeFilter.Add(".png");
            picker.FileTypeFilter.Add(".jpeg");

            StorageFile file = await picker.PickSingleFileAsync();
            // 打开文件流
            IRandomAccessStream stream = await file?.OpenReadAsync();
            // 插入图片
            editbox.Document.Selection.InsertImage(400, 300, 0, Windows.UI.Text.VerticalCharacterAlignment.Baseline, "图像", stream);
        }

        private void OnBold(object sender, RoutedEventArgs e)
        {
            // FormatEffect.Toggle表示切换状态
            editbox.Document.Selection.CharacterFormat.Bold = Windows.UI.Text.FormatEffect.Toggle;
        }

        private void OnItalic(object sender, RoutedEventArgs e)
        {
            editbox.Document.Selection.CharacterFormat.Italic = FormatEffect.Toggle;
        }

        private void OnUnderline(object sender, RoutedEventArgs e)
        {
            ITextCharacterFormat format = editbox.Document.Selection.CharacterFormat;
            if (format.Underline == UnderlineType.Single )
            {
                format.Underline = UnderlineType.None;
            }
            else
            {
                format.Underline = UnderlineType.Single;
            }
        }
    }
}
